
## CATO-CLI - query.site.cloudInterconnectPhysicalConnection:
[Click here](https://api.catonetworks.com/documentation/#query-query.site.cloudInterconnectPhysicalConnection) for documentation on this operation.

### Usage for query.site.cloudInterconnectPhysicalConnection:

```bash
catocli query site cloudInterconnectPhysicalConnection -h

catocli query site cloudInterconnectPhysicalConnection <json>

catocli query site cloudInterconnectPhysicalConnection --json-file query.site.cloudInterconnectPhysicalConnection.json

catocli query site cloudInterconnectPhysicalConnection '{"cloudInterconnectPhysicalConnectionInput":{"id":"id"}}'

catocli query site cloudInterconnectPhysicalConnection '{
    "cloudInterconnectPhysicalConnectionInput": {
        "id": "id"
    }
}'
```

#### Operation Arguments for query.site.cloudInterconnectPhysicalConnection ####

`accountId` [ID] - (required) N/A    
`cloudInterconnectPhysicalConnectionInput` [CloudInterconnectPhysicalConnectionInput] - (required) N/A    
